#!/bin/bash
# © Copyright [2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

# Start the CIS Dashboard process
nohup /opt/novell/cis/bin/cisdashboard nodes &
child=$!
status=$?
if [ $status -ne 0 ]; then
  echo "Failed to start dashboard Service: $status"
  exit $status
fi

# Start the Envoy sidecar process
nohup /envoy/envoy -c /envoy/envoy_dashboard.json &
echo "envoy started"
status=$?
if [ $status -ne 0 ]; then
  echo "Failed to start Envoy as a Sidecar in oes-dashboard: $status"
  exit $status
fi

# Start Consul as a Agent
nohup /consul/consul agent -config-dir=/etc/consul.d -data-dir=/consul -node=oes-dashboard -log-level=warn -retry-join cis-gateway > /dev/null 2>&1 &
status=$?
if [ $status -ne 0 ]; then
  echo "Failed to start Consul server: $status"
  exit $status
fi

trap terminate TERM
terminate()
{
    echo "Signal received, stopping..."
    kill -TERM "$child" 2>/dev/null
    wait "$child"
    echo "Main process exited gracefully."
    /consul/consul leave
    echo "Gracefully exited Consul agent."
    exit 0
}

# Health check for the services that are invoked above.
# The container exits with an error if any one of the three processes has exited.
# Otherwise it loops forever, waking up every 60 seconds.

while true; do
  sleep 60&
  wait $!
  ps aux |grep /opt/novell/cis/bin/cisdashboard |grep -q -v grep
  CIS_SERVICE_STATUS=$?
  ps aux |grep envoy/envoy |grep -q -v grep
  ENVOY_STATUS=$?
  ps aux |grep consul/consul |grep -q -v grep
  CONSUL_STATUS=$?
  
  # Exit the Script with PID 1 in container, which in turn causes the container to go down 
  if [ $CIS_SERVICE_STATUS -ne 0 -o $ENVOY_STATUS -ne 0 -o $CONSUL_STATUS -ne 0 ]; then
    echo "One of the processes has already exited."
    echo "CIS_SERVICE_STATUS"
    echo $CIS_SERVICE_STATUS
    echo "ENVOY_STATUS"
    echo $ENVOY_STATUS
    echo "CONSUL_STATUS"
    echo $CONSUL_STATUS
    kill -TERM "$child" 2>/dev/null
    wait "$child"
    /consul/consul leave 2>/dev/null
    exit 1
  fi
done